import React, { useEffect } from 'react'
// import Chip from '@material-ui/core/Chip'
import Chip from '@mui/material/Chip'
import { makeStyles } from '@material-ui/core/styles'
//import TextField from '@material-ui/core/TextField'
import TextField from '@mui/material/TextField'
import Downshift from 'downshift'
import Typography from '@mui/material/Typography'
import Box from '@mui/material/Box'
import IconButton from '@mui/material/IconButton'
import HighlightOffOutlinedIcon from '@mui/icons-material/HighlightOffOutlined'
import { Tooltip, styled, tooltipClasses } from '@mui/material'
//import CancelIcon from '@material-ui/icons/Cancel' //Not used

const useStyles = makeStyles((theme) => ({
  placeholderText: {
    '& input::placeholder': {
      fontSize: 15,
    },
  },
  chip: {
    margin: theme.spacing(0.5, 0.25),
  },
  chipText: {
    '& .MuiChip-label': {
      fontSize: 15,
      overflowWrap: 'break-word',
      whiteSpace: 'normal',
      textOverflow: 'clip',
    },
    '& .MuiChip-deleteIcon': { height: 18 },
  },
}))

const CustomTooltip = styled(({ className, ...props }) => (
  <Tooltip {...props} classes={{ popper: className }} disableInteractive />
))(({ theme }) => ({
  [`& .${tooltipClasses.tooltip}`]: {
    backgroundColor: '#1877F2',
    color: '#FFFFFF',
    boxShadow: theme.shadows[1],
    borderRadius: 8,
    borderColor: '#1877F2',
    border: '2px solid #1877F2',
    fontSize: 11,
    //fontWeight: "bold",
  },
  [`& .${tooltipClasses.arrow}`]: {
    fontSize: 20,
    color: '#FFFFFF',
    '&::before': {
      backgroundColor: '#1877F2',
      border: '2px solid #1877F2',
    },
  },
}))

export const ReactTagsInput = ({ ...props }) => {
  const classes = useStyles()
  const {
    selectedTags,
    selectedItem,
    setSelectedItem,
    placeholder,
    tags,
    labelname,
    readOnlyTagInput,
    ...other
  } = props
  const [inputValue, setInputValue] = React.useState('')
  //const [selectedItem, setSelectedItem] = React.useState([])
  useEffect(() => {
    setSelectedItem(tags)
  }, [tags])
  useEffect(() => {
    setSelectedItem(selectedItem)
    selectedTags(selectedItem)
  }, [selectedItem, selectedTags])

  function handleKeyDown(event) {
    if (event.key === 'Enter') {
      const newSelectedItem = [...selectedItem]
      const duplicatedValues = newSelectedItem?.indexOf(
        event.target.value.trim()
      )

      if (duplicatedValues !== -1) {
        setInputValue('')
        return
      }
      if (!event.target.value?.replace(/\s/g, '').length) return

      newSelectedItem?.push(event.target.value.trim())
      setSelectedItem(newSelectedItem)
      setInputValue('')
    }
    if (
      selectedItem?.length &&
      !inputValue?.length &&
      event.key === 'Backspace'
    ) {
      if (readOnlyTagInput === false)
        // dont allow backspace if read only mode
        setSelectedItem(selectedItem?.slice(0, selectedItem?.length - 1))
    }
  }
  function handleChange(item) {
    let newSelectedItem = [...selectedItem]
    if (newSelectedItem?.indexOf(item) === -1) {
      newSelectedItem = [...newSelectedItem, item]
    }
    setInputValue('')
    setSelectedItem(newSelectedItem)
  }

  const handleDelete = (item) => () => {
    const newSelectedItem = [...selectedItem]
    newSelectedItem?.splice(newSelectedItem?.indexOf(item), 1)
    setSelectedItem(newSelectedItem)
  }
  function handleClearAll() {
    setInputValue('')
    setSelectedItem([])
  }
  function handleInputChange(event) {
    setInputValue(event.target.value)
  }
  return (
    <Downshift
      id="downshift-multiple"
      //type="button"
      inputValue={inputValue}
      onChange={handleChange}
      selectedItem={selectedItem}
    >
      {({ getInputProps }) => {
        const { onBlur, onChange, onFocus, ...inputProps } = getInputProps({
          onKeyDown: handleKeyDown,
          placeholder,
        })
        return (
          <div>
            <Box sx={{ display: 'flex', justifyContent: 'space-between' }}>
              {' '}
              <Typography component="span" variant="body2" sx={{ mb: 1 }}>
                <b>{labelname}</b>
              </Typography>
              {selectedItem?.length > 0 && readOnlyTagInput === false && (
                <CustomTooltip title={'Clear All ' + labelname} arrow>
                  <IconButton
                    onClick={() => handleClearAll()}
                    style={{
                      padding: 0,
                      height: 'fit-content',
                    }}
                  >
                    <HighlightOffOutlinedIcon
                      style={{
                        color: 'red',
                        fontSize: '1rem',
                      }}
                    />
                  </IconButton>
                </CustomTooltip>
              )}{' '}
            </Box>
            <stack direction="row">
              <TextField
                type="text"
                size="small"
                sx={{
                  width: '100%',
                  display: 'flex',
                }}
                classes={{ root: classes.placeholderText }} //placeholder text css
                onKeyDown={(e) => {
                  if (e.key === 'Enter') e.preventDefault()
                }}
                InputProps={{
                  readOnly: readOnlyTagInput ? true : false,
                  style: {
                    display: 'flex',
                    flexWrap: 'wrap',
                  },

                  startAdornment: selectedItem?.map((item) => (
                    <Box sx={{ mt: 1, mr: 1 }}>
                      <Chip
                        key={item}
                        tabIndex={-1}
                        label={item}
                        sx={{ p: 1 }}
                        className={classes.chipText}
                        //Don't allow pointer when it is read pnly
                        style={{
                          pointerEvents: readOnlyTagInput ? 'none' : 'auto',
                          height: 'auto', //adjust height when chip label test is wrapped
                        }}
                        //onDelete={handleDelete(item)}
                        //Don't allow to delete when it is read pnly
                        onDelete={
                          readOnlyTagInput ? () => {} : handleDelete(item)
                        }
                        //Don't disable when it is read pnly
                        //disabled={readOnlyTagInput ? true : false}
                        // deleteIcon={<CancelIcon disabled={readOnlyTagInput ? true : false}/>}
                        // InputProps={{
                        //   readOnly: readOnlyTagInput ? true : false
                        // }}
                      />
                    </Box>
                  )),
                  // endAdornment: (
                  //   <InputAdornment position="start">
                  //     <IconButton
                  //       onClick={() => {
                  //         console.log('CLear all')
                  //       }}
                  //     >
                  //       <CloseOutlinedIcon />
                  //     </IconButton>
                  //   </InputAdornment>
                  // ),

                  onBlur,
                  onChange: (event) => {
                    handleInputChange(event)
                    onChange(event)
                  },
                  onFocus,
                }}
                {...other}
                {...inputProps}
              />
              {/* {selectedItem.length > 0 && readOnlyTagInput === false && (
                <CustomTooltip title={'Clear All'} arrow>
                  <IconButton onClick={() => handleClearAll()}>
                    <HighlightOffOutlinedIcon style={{ color: 'red' }} />
                  </IconButton>
                </CustomTooltip>
                )} */}
            </stack>
          </div>
        )
      }}
    </Downshift>
  )
}
